@@ -335,7 +335,7 @@ OptimizerMbo = R6Class("OptimizerMbo",
           {
             self$surrogate$update()
           }, surrogate_update_error = function(error_condition) {
-            lg = lgr::get_logger("bbotk")
+            lg = lgr::get_logger("mlr3/bbotk")
             lg$warn("Could not update the surrogate a final time after the optimization process has terminated.")
           }
         )
